@@ -13,20 +13,15 @@ class task(base):
         super().__init__(token)
 
     def list(self, pageNum=1, pageSize=10):
-        api_name = "manager/live_room/list"
+        api_name = "manager/task/list"
         data = {
             "pageNum": pageNum,
             "pageSize": pageSize,
         }
         return self.request(api_name, data)
 
-    def sync(self, order_code):
-        api_name = "manager/order/order_invoice"
-        data = {"orderCodes": order_code}
-        return self.request(api_name, data, method="POST")
-
     def create(self, data):
-        api_name = ""
+        api_name = "manager/task/add"
         return self.request(api_name, data, method="POST")
 
     def read(self, _id):
@@ -35,24 +30,12 @@ class task(base):
             "id": _id,
         }
         response = self.request(api_name, data, method="GET")
-        # print(response)
         return self.response(response)
 
     def update(self, data):
         api_name = "manager/task/update"
         response = self.request(api_name, data, method="POST")
-        print(response)
-        # return self.response(response)
-
-    def updateDemo(self):
-        data = {
-            "id": 230,
-            "storeList": [
-                {"id": 1290, "type": 0, "parentId": 1289}
-            ],
-        }
-        return self.update(data)
-
+        return self.response(response)
 
     def delete(self):
         pass
